@@ -3,7 +3,7 @@
 
 VIZZU_STORY = "https://cdn.jsdelivr.net/npm/vizzu-story@~0.1.0/dist/vizzu-story.min.js"
 
-DISPLAY_INDENT = "            "
+DISPLAY_INDENT = "    "
 
 DISPLAY_TEMPLATE = """
 <div>
@@ -14,11 +14,13 @@ DISPLAY_TEMPLATE = """
 
         const vizzuPlayerData = {vizzu_player_data};
         const vizzuPlayer = document.getElementById("{id}")
+        // story.set_size()
+        {chart_size}
         vizzuPlayer.slides = vizzuPlayerData;
         vizzuPlayer.vizzu.initializing.then(chart => {{
-            // chart.feature()
+            // story.set_feature()
             {chart_features}
-            // chart.on()
+            // story.add_event()
             {chart_events}
         }});
     </script>
